"use client";
import React, { useEffect, useState } from "react";
import Image from "next/image";
import Link from "next/link";
import { useSearchParams } from "next/navigation";

import {
  FaceBookIcon,
  InstaIcon,
  LocationIcon,
  TwitterIcon,
  WhatsAppIcon,
  WhiteLinkdInIcon,
} from "@/components/Icons";
import PaginationComponent from "../Pagination";

export const CarListingCard = ({ initialData }) => {
  const searchParams = useSearchParams();
  const [currentPage, setCurrentPage] = useState(1);
  const [data, setData] = useState(initialData);
  const totalPages = 4; // Total number of pages

  const modifiedData = [
    ...data.slice(0, 3),
    { isAd: true }, // Adding a placeholder object for the ad
    ...data.slice(3),
  ];
  useEffect(() => {
    const fetchData = async () => {
      const params = new URLSearchParams(searchParams);
      const res = await fetch(
        `${process.env.NEXT_PUBLIC_BASE_URL}/car/filter?${params.toString()}`
      );
      const result = await res.json();
      setData(result);
    };

    fetchData();
  }, [searchParams]);

  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
  };
  return (
    <div className="flex flex-col w-full xl:me-20 gap-6">
      {modifiedData.map((item, index) => {
        if (item.isAd) {
          return (
            <figure key={`ad-${index}`} className="w-full">
              <Image
                src="/assets/images/ads.png"
                className="w-full min-h-[115px] rounded object-cover"
                height={168}
                width={955}
                alt="ads"
              />
            </figure>
          );
        }
        return (
          <div
            key={item._id}
            className="custom-shadow items-center flex-col sm:flex-row w-full p-3 xl:p-5 rounded flex gap-10"
          >
            <figure className="flex items-center lg:min-w-[352px]">
              <Link href={`car/${item._id}`}>
                <Image
                  className="rounded"
                  src={item?.thumbnailImg?.images[0]?.url}
                  height={253}
                  width={352}
                  alt="car"
                />
              </Link>
            </figure>
            <div className="">
              <p className="text-reefGold text-sm">Toyota</p>
              <Link href={`car/${item._id}`}>
                <h2 className="fs-40 font-semibold">{item.title}</h2>
              </Link>
              <p className="text-reefGold mb-3">{item.price} USD</p>
              <div className="flex flex-wrap gap-3 items-center mb-3">
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.year}</span>
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.kilometers} km</span>
                <span className="bg-[#F5F5F5] shrink-0 rounded-full h-[25px] w-[25px] "></span>
                <span>{item.steeringSide}</span>
              </div>
              <div className="flex gap-3 items-center mb-3">
                <LocationIcon className="text-reefGold" />
                <p>{item.country}</p>
              </div>
              <div>
                <p className="mb-3">Share With:</p>
                <div className="flex gap-3">
                  <Link href="#">
                    <FaceBookIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <InstaIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhiteLinkdInIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <TwitterIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhatsAppIcon className="h-[21px] w-[21px]" />
                  </Link>
                </div>
              </div>
            </div>
          </div>
        );
      })}
      <PaginationComponent
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
    </div>
  );
};
